from django.utils import unittest
from anora.templatetags.anora import anora

class AnoraTestCase(unittest.TestCase):

	def test_anora(self):
		awords = ['rabbit', 'mole', 'fox']
		anwords = ['owl', 'ox', 'octopus']

		for an_a, word_list in (('a', awords), ('an', anwords)):
			for word in word_list:
				self.assertEqual(' '.join((an_a, word)), anora(word))


"""
Anora is a simple_tag for Django that determines whether or not a word should have an "a" or "an" in front of it. Adds either one of these depending on the phoentic value of the given text.
"""

__version__ = '0.1.0'



import re

from django import template
from django.conf import settings
from django.utils.encoding import force_unicode
from django.template.defaultfilters import stringfilter

register = template.Library()

CONSONANT_SOUND = re.compile(r'''one(![ir])''', re.IGNORECASE|re.VERBOSE)
VOWEL_SOUND = re.compile(r'''[aeio]|u([aeiou]|[^n][^aeiou]|ni[^dmnl]|nil[^l])|h(ier|onest|onou?r|ors\b|our(!i))|[fhlmnrsx]\b''', re.IGNORECASE|re.VERBOSE)

@register.filter
def anora(text):
    text = force_unicode(text)
    anora = 'an' if not CONSONANT_SOUND.match(text) and VOWEL_SOUND.match(text) else 'a'
    return anora + ' ' + text